@@ -576,7 +576,18 @@ class StandardAcquisition(BaseAcquisition):
             detector_node["count_time"] = self._acq_expo_time
             detector_node["count_time"].attrs["unit"] = "s"
         # write distance
-        distance, unit = self._get_distance()
+        if (
+            TomoHDF5Config.EXTRA_PARAMS_DISTANCE
+            in self.configuration.param_already_defined
+        ):
+            distance = float(
+                self.configuration.param_already_defined[
+                    TomoHDF5Config.EXTRA_PARAMS_DISTANCE
+                ]
+            )
+            unit = "m"
+        else:
+            distance, unit = self._get_distance()
         if distance is not None:
             detector_node["distance"] = distance
             detector_node["distance"].attrs["unit"] = unit
